@@ -5,13 +5,14 @@ APP_ROOT = Path(__file__).parent.absolute()
 
 ''' [ T Cell Class I ] '''
 # Path to the IEDB T cell class I tool (required)
-tcell_class_i_path=None
+tcell_class_i_path='/mnt/c/Users/USER/Downloads/ng_tc1-0.1.2-beta'
 
 # Path to the IEDB T cell class I/II virtual environment (optional)
-tcell_class_i_venv=None
+tcell_class_i_venv='/home/hkim/.pyenv/versions/3.9.5/envs/venv-mhci-stand-test-2'
 
 # Name of the environment module to be activated (optional).
 # Most users can keep this as None
+# tcell_class_i_module='python/3.10.5'
 tcell_class_i_module=None
 
 # If using a different Python environment or binary for this tool compared to others,
@@ -22,10 +23,10 @@ tcell_class_i_lib_path=None
 
 ''' [ T Cell Class II ] '''
 # Path to the IEDB T cell class II tool (required)
-tcell_class_ii_path=None
+tcell_class_ii_path='/mnt/c/Users/USER/Downloads/IEDB_NG_TC2-0.2.2-beta/ng_tc2-0.2.2-beta'
 
 # Path to the IEDB T cell class II virtual environment (optional)
-tcell_class_ii_venv=None
+tcell_class_ii_venv='/home/hkim/.pyenv/versions/venv-mhcii_exec'
 
 # Name of the environment module to be activated (optional).
 # Most users can keep this as None
